@@ -66,11 +66,14 @@ class Datenreihe(object):
         else:
             w_finite = self.werte[np.isfinite(self.werte)]
             n_invalid = len(self.werte) - len(w_finite)
-            w_min = w_finite.min()
-            w_max = w_finite.max()
-            infostring = u'%-40s %d Werte von %g bis %g' % (infostring, len(self.werte) - n_invalid, w_min, w_max)
-            if n_invalid:
-                infostring += u' (und %d ungültige Werte)' % n_invalid
+            if len(w_finite):
+                w_min = w_finite.min()
+                w_max = w_finite.max()
+                infostring = u'%-40s %d Werte von %g bis %g' % (infostring, len(self.werte) - n_invalid, w_min, w_max)
+                if n_invalid:
+                    infostring += u' (und %d ungültige Werte)' % n_invalid
+            else:
+                infostring = u'%-40s (%d ungültige Werte)' % (infostring, n_invalid)
 
         try:
             print(infostring)
